@@ -7,11 +7,11 @@ use Types::Standard -types;
 
 use namespace::autoclean;
 
-use version; our $VERSION = version->declare('v0.1.0');
+use version; our $VERSION = version->declare('v0.1.1');
 
 =head1 NAME
 
-File::Rotate::Simple - no-frills fill rotation
+File::Rotate::Simple - no-frills file rotation
 
 =head1 SYNOPSIS
 
@@ -138,7 +138,7 @@ sub _build_files {
 
 =head1 METHODS
 
-head2 C<rotate>
+=head2 C<rotate>
 
 Rotates the files.
 
